/**
 * Implements browser detection.
 */
export default class BrowserDetection {
    _bowser: any;
    _name: any;
    _version: any;
    /**
     * Creates new BrowserDetection instance.
     *
     * @param {Object} [browserInfo] - Information about the browser.
     * @param {string} browserInfo.name - The name of the browser.
     * @param {string} browserInfo.version - The version of the browser.
     */
    init(browserInfo?: any): void;
    /**
     * Gets current browser name.
     * @returns {string}
     */
    getName(): any;
    /**
     * Checks if current browser is Chrome.
     * @returns {boolean}
     */
    isChrome(): boolean;
    /**
     * Checks if current browser is Opera.
     * @returns {boolean}
     */
    isOpera(): boolean;
    /**
     * Checks if current browser is Firefox.
     * @returns {boolean}
     */
    isFirefox(): boolean;
    /**
     * Checks if current browser is Internet Explorer.
     * @returns {boolean}
     */
    isIExplorer(): boolean;
    /**
     * Checks if current browser is Safari.
     * @returns {boolean}
     */
    isSafari(): boolean;
    /**
     * Checks if current environment is NWJS.
     * @returns {boolean}
     */
    isNWJS(): boolean;
    /**
     * Checks if current environment is Electron.
     * @returns {boolean}
     */
    isElectron(): boolean;
    /**
     * Checks if current environment is React Native.
     * @returns {boolean}
     */
    isReactNative(): boolean;
    /**
     * Returns the version of the current browser.
     * @returns {string}
     */
    getVersion(): any;
    isMobile(): boolean;
    getDeviceInfo: () => {
        isMobile: boolean;
        browserName: any;
        osName: any;
        browserVersion: any;
        osVersionName: any;
        engineName: any;
    };
    /**
     * Check if the parsed browser matches the passed condition.
     *
     * @param {Object} checkTree - It's one or two layered object, which can include a
     * platform or an OS on the first layer and should have browsers specs on the
     * bottom layer.
     * Eg. { chrome: '>71.1.0' }
     *     { windows: { chrome: '<70.2' } }
     * @returns {boolean | undefined} - Returns true if the browser satisfies the set
     * conditions, false if not and undefined when the browser is not defined in the
     * checktree object or when the current browser's version is unknown.
     * @private
     */
    _checkCondition(checkTree: any): any;
    /**
     * Compares the passed version with the current browser version.
     *
     * @param {*} version - The version to compare with. Anything different
     * than string will be converted to string.
     * @returns {boolean|undefined} - Returns true if the current version is
     * greater than the passed version and false otherwise. Returns undefined if
     * the current browser version is unknown.
     */
    isVersionGreaterThan(version: any): any;
    /**
     * Compares the passed version with the current browser version.
     *
     * @param {*} version - The version to compare with. Anything different
     * than string will be converted to string.
     * @returns {boolean|undefined} - Returns true if the current version is
     * lower than the passed version and false otherwise. Returns undefined if
     * the current browser version is unknown.
     */
    isVersionLessThan(version: any): any;
    /**
     * Compares the passed version with the current browser version.
     *
     * @param {*} version - The version to compare with. Anything different
     * than string will be converted to string.
     * @returns {boolean|undefined} - Returns true if the current version is
     * equal to the passed version and false otherwise. Returns undefined if
     * the current browser version is unknown.
     * A loose-equality operator is used here so that it matches the sub-versions as well.
     */
    isVersionEqualTo(version: any): any;
}
