import DyteEventEmitter from '../utils/DyteEventEmitter';
import DyteSelf from './DyteSelf';
export interface PollOption {
    text: string;
    votes: {
        id: string;
        name: string;
    }[];
    count: number;
}
export interface Poll {
    id: string;
    question: string;
    options: PollOption[];
    anonymous: boolean;
    hideVotes: boolean;
    createdBy: string;
    createdByUserId: string;
    voted: string[];
}
export interface PollCreatePayload {
    question: string;
    options: string[];
    anonymous: boolean;
    hideVotes: boolean;
    createdBy: string;
    createdByUserId: string;
}
export interface PollVotePayload {
    pollId: string;
    index: number;
}
/**
 * The DytePolls module consists of the polls that have been created in the meeting.
 * @module DytePolls
 * @typicalname meeting.polls
 */
export default class DytePolls extends DyteEventEmitter {
    #private;
    /**
     * An array of poll items.
     */
    items: Poll[];
    constructor(self: DyteSelf);
    /**
     * Creates a poll in the meeting.
     * @param question The question that is to be voted for.
     * @param options The options of the poll.
     * @param anonymous If true, the poll votes are anonymous.
     * @param hideVotes If true, the votes on the poll are hidden.
     */
    create(question: string, options: string[], anonymous?: boolean, hideVotes?: boolean): Promise<void>;
    /**
     * Casts a vote on an existing poll.
     * @param pollId The ID of the poll that is to be voted on.
     * @param index The index of the option.
     */
    vote(id: string, index: number): Promise<void>;
}
