import DyteEventEmitter from '../utils/DyteEventEmitter';
import DyteSelf from './DyteSelf';
import DyteParticipants from './DyteParticipants';
import DyteRemoteRequest from './DyteRemoteRequest';
import DyteRemoteMap from './map/DyteRemoteMap';
/**
 * This module provides the ability to control a remotely shared screen using mouse and keyboard.
 * Methods are available to request, accept and end control of shared screen.
 * @module DyteRemote
 * @typicalname meeting.remote
 */
export default class DyteRemote extends DyteEventEmitter {
    #private;
    incomingRequests: DyteRemoteMap;
    outgoingRequests: DyteRemoteMap;
    active: DyteRemoteRequest | null;
    constructor(roomNodeClient: any, self: DyteSelf, participants: DyteParticipants);
    /**
     * Sends a request to a peer for remote control.
     * @param peerId The peer that needs to receive the remote control request
     * @returns request identifier for the control request.
     */
    requestControl(peerId: string): Promise<string>;
    /**
     * Accepts a remote control request from a peer.
     * @param requestId The request identifier that needs to be accepted
     */
    acceptControl(requestId: string): Promise<void>;
    /**
     * End an active remote control.
     */
    endControl(): Promise<void>;
    keyboardEvent(event: KeyboardEvent): Promise<void>;
    mouseEvent(event: MouseEvent | WheelEvent, screenShareVideoElement: HTMLVideoElement): Promise<void>;
    private static getFormattedRemoteMouseEvent;
    private static getFormattedKeyboardEvent;
}
