interface EnabledInner {
    isEnabled: boolean;
}
/**
 * TODO(roerohan): separate the inner objects into separate interfaces
 * so that we can use the same types in the get methods in the
 * class instead of having to rewrite them.
 */
export interface PresetTheme {
    setupScreen: EnabledInner;
    aloneHere: EnabledInner;
    waitingRoom: {
        isEnabled: boolean;
        enablePreview: boolean;
    };
    controlBar: {
        isEnabled: boolean;
        elements: {
            plugins: boolean;
            screenshare: boolean;
            invite: boolean;
            participants: boolean;
            chat: boolean;
            reactions: boolean;
            polls: boolean;
            fullscreen: boolean;
            layout: boolean;
        };
    };
    header: {
        isEnabled: boolean;
        elements: {
            logo: string;
            timer: boolean;
            title: boolean;
            participantCount: boolean;
            changeLayout: boolean;
        };
    };
    pipMode: boolean;
    autoTune: boolean;
    grid: {
        multi: {
            maxVideoCount: number;
            videoFit: string;
        };
        single: {
            maxVideoCount: number;
            videoFit: string;
        };
        defaultView: string;
    };
    colors: {
        primary: string;
        secondary: string;
        text: string;
        background: string;
        textPrimary: string;
        videoBackground: string;
    };
    controls: {
        pipToggle: boolean;
    };
}
export declare const DEFAULT_THEME_CAMEL_CASED: {
    setupScreen: {
        isEnabled: boolean;
    };
    aloneHere: {
        isEnabled: boolean;
    };
    waitingRoom: {
        isEnabled: boolean;
        enablePreview: boolean;
    };
    controlBar: {
        isEnabled: boolean;
        elements: {
            plugins: boolean;
            screenshare: boolean;
            invite: boolean;
            participants: boolean;
            chat: boolean;
            reactions: boolean;
            polls: boolean;
            fullscreen: boolean;
            layout: boolean;
        };
    };
    header: {
        isEnabled: boolean;
        elements: {
            logo: string;
            timer: boolean;
            title: boolean;
            participantCount: boolean;
            changeLayout: boolean;
        };
    };
    pipMode: boolean;
    autoTune: boolean;
    grid: {
        multi: {
            maxVideoCount: number;
            videoFit: string;
        };
        single: {
            maxVideoCount: number;
            videoFit: string;
        };
        defaultView: string;
    };
    colors: {
        primary: string;
        secondary: string;
        text: string;
        background: string;
        textPrimary: string;
        videoBackground: string;
    };
    controls: {
        pipToggle: boolean;
    };
};
/**
 * The DyteThemePreset class represents the meeting theme for the current participant
 * @module DyteThemePreset
 * @typicalname meeting.self.suggestedTheme
 */
export default class DyteThemePreset {
    #private;
    private constructor();
    static fromResponse(theme: PresetTheme): DyteThemePreset;
    static default(): DyteThemePreset;
    /**
     * The `setupScreen` represents the setup screen for the meeting.
     */
    get setupScreen(): Readonly<EnabledInner>;
    /**
     * The `aloneHere` contains the properties to show a layout when
     * the participant is alone in the meeting.
     */
    get aloneHere(): Readonly<EnabledInner>;
    /**
     * The `waitingRoom` contains the properties to show a layout when
     * the participant is in waiting to join the meeting.
     */
    get waitingRoom(): Readonly<{
        isEnabled: boolean;
        enablePreview: boolean;
    }>;
    /**
     * The `controlBar` contains the properties to show the meeting control bar with
     * various action buttons for the meeting.
     * The `elements` key contains the various action buttons.
     */
    get controlBar(): Readonly<{
        isEnabled: boolean;
        elements: {
            plugins: boolean;
            screenshare: boolean;
            invite: boolean;
            participants: boolean;
            chat: boolean;
            reactions: boolean;
            polls: boolean;
            fullscreen: boolean;
            layout: boolean;
        };
    }>;
    /**
     * The `header` contains the properties to show the meeting header with various elements.
     * The `elements` key contains the following properties
     * `logo` - string value representing the public URL for the logo
     * `timer` - boolean value suggesting if the timer should be shown
     * `title` - boolean value suggesting if the meeting title should be shown
     * `participantCount` - boolean value suggesting if the participant count shuld be shown
     * `changeLayout` - boolean value suggesting if the participant can change layout
     */
    get header(): Readonly<{
        isEnabled: boolean;
        elements: {
            logo: string;
            timer: boolean;
            title: boolean;
            participantCount: boolean;
            changeLayout: boolean;
        };
    }>;
    /**
     * The `pipMode` property returns a boolean value
     * If true, picture-in-picture mode is enabled for the participant.
     */
    get pipMode(): Readonly<boolean>;
    /**
     * The `autoTune` property returns a boolean value
     * If true, force the participant's video to be in compatibility mode.
     */
    get autoTune(): Readonly<boolean>;
    /**
     * The `grid` contains the properties to show participant grid for the meeting.
     * `defaultView` key points to the view type, possible values are `MULTI`, `SINGLE`
     * `multi` and `single` keys contain the following preferences to show grid layout.
     * `maxVideoCount` - number of participants to show in the grid.
     * `videoFit` - string value suggesting how to align the video content.
     */
    get grid(): Readonly<{
        multi: {
            maxVideoCount: number;
            videoFit: string;
        };
        single: {
            maxVideoCount: number;
            videoFit: string;
        };
        defaultView: string;
    }>;
    get colors(): Readonly<{
        primary: string;
        secondary: string;
        text: string;
        background: string;
        textPrimary: string;
        videoBackground: string;
    }>;
    get controls(): Readonly<{
        pipToggle: boolean;
    }>;
}
export {};
