import DyteEventEmitter from '../../utils/DyteEventEmitter';
import DyteMap, { DyteMapEvents } from './DyteMap';
import DyteParticipant from '../DyteParticipant';
/**
 * This is a map of participants, indexed by `participant.id` (a participant's peer ID).
 * This map emits an event whenever a participant present in the map emits an event.
 * For example, when a participant is added to this map, a `participantJoined` event is
 * emitted from the map. When a participant object emits an event `videoUpdate`, the map
 * re-emits that event (provided the participant is present in the map).
 * @module DyteParticipantMap
 * @typicalname meeting.participants.joined
 */
export default class DyteParticipantMap<T extends Pick<DyteParticipant, 'id' | keyof DyteEventEmitter> = DyteParticipant> extends DyteMap<T> {
    constructor(options?: DyteMapEvents);
    add(participant: T, emitEvent?: boolean): this;
    clear(emitEvent?: boolean, removeListeners?: boolean): void;
    delete(participantId: string, emitEvent?: boolean, removeListeners?: boolean): boolean;
}
