import { DyteMediaStreamConstraints, DyteMediaTrackConstraints } from './LocalMediaInterfaces';
export interface LocalAudioOptions {
    disableAP?: boolean;
    disableAEC?: boolean;
    disableNS?: boolean;
    disableAGC?: boolean;
    disableHPF?: boolean;
}
/**
 * To initialize an instance of this class, use the
 * `.init()` static method.
 */
export default class LocalMediaUtils {
    #private;
    private constructor();
    static init(): Promise<LocalMediaUtils>;
    static isDeviceListAvailable(): boolean;
    private static enumerateDevices;
    static getAudioConstraints(options: {
        audioDeviceId?: string;
        audioOptions?: LocalAudioOptions;
    }): DyteMediaStreamConstraints;
    static getVideoConstraints(options?: {
        videoDeviceId?: string;
        videoTrackConstraints?: boolean | DyteMediaTrackConstraints;
        facingMode?: string;
        frameRate?: ConstrainDouble;
    }): DyteMediaStreamConstraints;
    private static getUserMediaWithTimeout;
    static getAudioTrack(constraints: DyteMediaStreamConstraints): Promise<MediaStreamTrack>;
    static getVideoTrack(constraints: DyteMediaStreamConstraints): Promise<MediaStreamTrack>;
    static getScreenShareTracks(constraints: any): Promise<{
        video: MediaStreamTrack;
        audio: MediaStreamTrack;
    }>;
    static getAudioAndVideoTrack(constraints: DyteMediaStreamConstraints): Promise<{
        audioTrack: MediaStreamTrack;
        videoTrack: MediaStreamTrack;
    }>;
    onDeviceChange(callback: (ev?: Event, changedDevices?: {
        added: MediaDeviceInfo[];
        removed: MediaDeviceInfo[];
    }) => void): void;
    repopulateAvailableDevices(): Promise<void>;
    get availableDevices(): MediaDeviceInfo[];
    getAvailableDevicesByKind(kind: string): MediaDeviceInfo[];
    getDeviceById(deviceId: string, kind: 'audioinput' | 'audiooutput' | 'videoinput'): MediaDeviceInfo;
    /**
     * Returns all audio input devices (microphone devices).
     */
    getAudioDevices(): MediaDeviceInfo[];
    /**
     * Returns all video input devices.
     */
    getVideoDevices(): MediaDeviceInfo[];
    /**
     * Returns all audio output devices (speaker devices).
     */
    getSpeakerDevices(): MediaDeviceInfo[];
}
