import SocketClient, { WebsocketMessage } from '../sockets/SocketClient';
import DytePlugin from '../client/DytePlugin';
import { Message } from '../client/DyteChat';
import DyteRemoteRequest, { RemoteEventData } from '../client/DyteRemoteRequest';
import { PollCreatePayload, PollVotePayload } from '../client/DytePolls';
import LocalMediaHandler from '../media/LocalMediaHandler';
import { BroadcastMessagePayload } from '../client/DyteParticipants';
export default class RoomNodeClient {
    #private;
    maxPreferredStreams: number;
    legacyMode: boolean;
    roomNodeUrl: string;
    meetingTitle: string;
    roomName: string;
    peerId: string;
    authToken: string;
    roomJoined: boolean;
    peerDisplayName: string;
    isDisconnected: boolean;
    constructor(options: {
        roomName: string;
        roomNodeUrl: string;
        peerId: string;
        authToken: string;
        legacyMode: boolean;
        socketClient: SocketClient;
        localMediaHandler: LocalMediaHandler;
        meetingTitle: string;
    });
    static init(options: {
        legacyMode?: boolean;
        roomName: string;
        roomNodeUrl: string;
        peerId: string;
        authToken: string;
        meetingTitle: string;
    }, localMediaHandler: LocalMediaHandler): Promise<RoomNodeClient>;
    reconnect(): void;
    setupTransports(): Promise<void>;
    resetRoomNodeClient(): Promise<void>;
    handleSocketCallbacks(message: WebsocketMessage): Promise<void>;
    handleSockets(message: WebsocketMessage, callBack?: (arg?: string) => void): Promise<void>;
    joinRoom(displayName: string, audioMuted: boolean, roomTitle?: string, currentUserSharedMediaStates?: {
        audio?: boolean;
        video?: boolean;
        screen?: boolean;
    }): Promise<WebsocketMessage>;
    leaveRoom(): Promise<void>;
    private handleProducerClosed;
    getConsumers(): Map<string, import("./SFUHandler").ExtendedConsumer>;
    private handleConsumerScore;
    private handleProducerScore;
    shareWebcam(videoTrack?: MediaStreamTrack): Promise<void>;
    shareScreen(tracks: {
        video?: MediaStreamTrack;
        audio?: MediaStreamTrack;
    }): Promise<void>;
    shareMic(audioTrack?: MediaStreamTrack): Promise<void>;
    pauseMic(): void;
    pauseWebcam(): Promise<void>;
    resumeMic(): Promise<void>;
    resumeWebcam(): Promise<void>;
    disableWebcam(): Promise<void>;
    disableMic(): Promise<void>;
    disableScreenShare(): Promise<void>;
    resetVideoProducers(videoTrack: MediaStreamTrack, screenShareTrack?: MediaStreamTrack): Promise<void>;
    getRoomState(): Promise<WebsocketMessage>;
    changeRoomDisplayTitle(displayTitle: string): Promise<void>;
    sendMessage(message: WebsocketMessage): Promise<WebsocketMessage>;
    broadcastMessage(type: string, messagePayload: BroadcastMessagePayload): Promise<WebsocketMessage>;
    sendChatMessage(message: Omit<Message, 'time' | 'type' | 'id'> & {
        time: number;
        type: number;
    }): Promise<void>;
    getChatMessages(): Promise<WebsocketMessage>;
    pinChatMessage(payload: {
        id: string;
    }): Promise<WebsocketMessage>;
    unpinChatMessage(payload: {
        id: string;
    }): Promise<WebsocketMessage>;
    getPolls(): Promise<WebsocketMessage>;
    newPoll(poll: PollCreatePayload): Promise<void>;
    votePoll(poll: PollVotePayload): Promise<void>;
    acceptWaitingRequest(peerId: string): Promise<void>;
    rejectWaitingRequest(peerId: string): Promise<void>;
    muteAll(allowUnMute: boolean): Promise<void>;
    muteAllVideo(): Promise<void>;
    pinPeer(peerId: string): Promise<WebsocketMessage>;
    unpinPeer(peerId: string): Promise<WebsocketMessage>;
    disableAudio(peerId: string): Promise<void>;
    disableVideo(peerId: string): Promise<void>;
    kickAll(): Promise<void>;
    kick(peerId: string): Promise<void>;
    getPage(pageNum: number): Promise<WebsocketMessage>;
    muteSelf(): Promise<void>;
    unmuteSelf(): Promise<void>;
    addRoomPlugin(plugin: Pick<DytePlugin, 'id' | 'staggered'>): Promise<WebsocketMessage>;
    removeRoomPlugin(plugin: Pick<DytePlugin, 'id'>): Promise<WebsocketMessage>;
    private remoteControlMessage;
    requestRemoteControl(request: DyteRemoteRequest): Promise<WebsocketMessage>;
    acceptRemoteControl(request: DyteRemoteRequest): Promise<WebsocketMessage>;
    terminateRemoteControl(peerId: string, request: DyteRemoteRequest): Promise<WebsocketMessage>;
    sendEventRemoteControl(peerId: string, remoteRequestId: string, remoteEvent: RemoteEventData): Promise<WebsocketMessage>;
}
